#
# spec file for package python-stevedore
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-stevedore
Version:        5.3.0
Release:        1.1
Summary:        Manage dynamic plugins for Python applications
License:        Apache-2.0
URL:            https://docs.openstack.org/stevedore/latest/
Source:         https://files.pythonhosted.org/packages/source/s/stevedore/stevedore-%{version}.tar.gz
BuildRequires:  %{python_module pbr >= 2.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module Sphinx >= 2.0.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module testtools}
# /SECTION
BuildRequires:  fdupes
Requires:       python-importlib-metadata
Requires:       python-pbr
%if "%{?python_provides}" == "python3"
Provides:       python3-stevedore = %{version}
Obsoletes:      python3-stevedore <= %{version}
%endif
BuildArch:      noarch
%python_subpackages

%description
Python makes loading code dynamically easy, allowing you to configure
and extend your application by discovering and loading extensions
(plugins) at runtime. Many applications implement their own
library for doing this, using ``__import__`` or ``importlib``.
stevedore avoids creating yet another extension
mechanism by building on top of setuptools entry points. The code
for managing entry points tends to be repetitive, though, so stevedore
provides manager classes for implementing common patterns for using
dynamically loaded extensions.

%prep
%autosetup -p1 -n stevedore-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc AUTHORS ChangeLog README.rst
%license LICENSE
%{python_sitelib}/stevedore
%{python_sitelib}/stevedore-%{version}.dist-info

%changelog
* Sun Sep  8 2024 Dirk Müller <dmueller@suse.com>
- update to 5.3.0:
  * reno: Update master for unmaintained/zed
  * Remove old excludes
  * Update master for stable/2024.1
  * reno: Update master for unmaintained/xena
  * reno: Update master for unmaintained/wallaby
  * reno: Update master for unmaintained/victoria
* Thu Mar 14 2024 Dirk Müller <dmueller@suse.com>
- update to 5.2.0:
  * Update python classifier in setup.cfg
  * Update master for stable/2023.2
* Thu Jan  4 2024 Dirk Müller <dmueller@suse.com>
- switch to singlespec to get multipe flavors
* Thu Jun 15 2023 cloud-devel@suse.de
- update to version 5.1.0
  - Moves supported python runtimes from version 3.8 to 3.10
  - Catch NotADirectoryError error
  - Update master for stable/2023.1
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
* Tue Mar  7 2023 cloud-devel@suse.de
- update to version 5.0.0
  - Remove Extension.extras
* Mon Jan  2 2023 cloud-devel@suse.de
- update to version 4.1.1
  - Update master for stable/yoga
  - Fix remaining logic to support Python 3.6/7
  - Fix compatibility with Python 3.12, importlib-metadata 5.0
  - Order old importlib-metadata results by group
  - Drop python3.6/3.7 support in testing runtime
  - Add Python3 antelope unit tests
  - Add Python3 zed unit tests
  - Update master for stable/zed
  - remove unicode from code
  - Fix compatibility with Python 3.10, 3.9.11
* Tue Jun  7 2022 cloud-devel@suse.de
- update to version 3.5.0
  - Add Python3 yoga unit tests
  - Rely on member access, the preferred access since importlib_metadata 4.8.
  - Update master for stable/xena
* Tue May 24 2022 Dirk Müller <dmueller@suse.com>
- remove unneeded dependencies
* Mon May  9 2022 Dirk Müller <dmueller@suse.com>
- skip test that fails with python 3.10
* Mon Dec  6 2021 cloud-devel@suse.de
- update to version 3.4.0
  - Use TOX_CONSTRAINTS_FILE
  - Update master for stable/wallaby
  - setup.cfg: Replace dashes with underscores
  - Add Python3 xena unit tests
  - Move flake8 as a pre-commit local target.
  - Remove lower-constraints remnants
  - Dropping lower constraints testing
  - Fix formatting of release list
* Sun May  2 2021 cloud-devel@suse.de
- update to version 3.3.0
  - Add Python3 wallaby unit tests
  - Fix cache dir flooding when running from /tmp
  - Use py3 as the default runtime for tox
  - Adding pre-commit
  - Update master for stable/victoria
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 3.2.2
  - Drop Python 2.7 support
  - sphinxext: fix warning message for detailed list
  - Switch to newer openstackdocstheme and reno versions
  - Replace external mock with built-in unittest.mock
  - Remove Travis CI config
  - switch to importlib.metadata package
  - fix supported python versions in documentation
  - Add Python3 victoria unit tests
  - add release note before major version update
  - add property methods to extension for more entry point values
  - Stop to use the __future__ module.
  - Remove dead files
  - Mark sphinx extensions thread safe
  - Update master for stable/ussuri
  - Fix the bug 1892610. There're some syntax errors in the comment of stevedore code.
* Tue May 12 2020 cloud-devel@suse.de
- update to version 1.32.0
  - Update the constraints url
  - Update master for stable/train
  - Blacklist sphinx 2.1.0 (autodoc bug)
  - Switch to Ussuri jobs
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 1.31.0
  - add python 3.7 unit test job
  - Dropping the py35 testing
  - Delete repeated param description.
  - Update master for stable/stein
  - Add local bindep.txt
  - update git.openstack.org to opendev
  - OpenDev Migration Patch
  - Add Python 3 Train unit tests
  - Cap Bandit below 1.6.0 and update Sphinx requirement
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.30.1
  - add lib-forward-testing-python3 test job
  - Update doc/conf.py to avoid warnings with sphinx 1.8
  - Removed older version of python added 3.5
  - Change openstack-dev to openstack-discuss
  - Update reno for stable/rocky
  - Use template for lower-constraints
  - add python 3.6 unit test job
  - Update sphinx logging to not use app object
  - fix wrong link
  - import zuul job settings from project-config
* Tue Jan 22 2019 Dirk Mueller <dmueller@suse.com>
- break build cycle with stestr (bsc#1121610)
* Wed Sep 19 2018 cloud-devel@suse.de
- update to version 1.29.0
  - set default python to python3
  - fix tox python3 overrides
  - Remove unnecessary py27 testenv
  - Update reno for stable/queens
  - Update links in README
  - Trivial: Update pypi url to new url
  - Switch to stestr
  - Follow the new PTI for document build
  - Updated from global requirements
  - add lower-constraints job
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 1.28.0
  - move doc requirements to doc/requirements.txt
  - Remove -U from pip install
  - add bandit to pep8 job
  - Update reno for stable/pike
  - Remove setting of version/release from releasenotes
  - Add an ExtensionManager.items() method
  - Make openstackdocstheme an optional doc dependency
  - Avoid tox_install.sh for constraints support
  - Move reno to optional docs requirements
  - Remove duplicate optional requirement
  - Remove Pillow from test-requirements
  - Updated from global requirements
* Thu Oct 26 2017 toddrme2178@gmail.com
- Provide python2-stevedore for compatibility with single-spec
  macros.
* Tue Aug 22 2017 cloud-devel@suse.de
- update to version 1.25.0
  - move documentation into the new standard layout
  - Remove 'run_sphinx' script
  - Remove unused doc/requirements.txt
  - turn on warning-is-error for doc build
  - Mark as Production/Stable instead of Alpha
  - Remove oslotest from test-requirements
  - Update URLs in documents according to document migration
  - fix setuptools url
  - Remove support for py34
  - Update reno for stable/ocata
  - Updated from global requirements
  - switch from oslosphinx to openstackdocstheme
* Tue Aug 22 2017 cloud-devel@suse.de
- update to version 1.20.1
  - Update UPPER_CONSTRAINTS_FILE for stable/ocata
  - Updated from global requirements
  - Update .gitreview for stable/ocata
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 1.20.0:
  - extension: add entry_point_names method
  - Add Constraints support
  - Fix typos in exception.py
  - Updated from global requirements
  - extension: expose _find_entry_points as list_entry_points
  - Show team and repo badges on README
  - Remove reference to non-existing page
  - Allow suppression of warnings from DriverManager
  - Add Apache 2.0 license to source file
  - Add reno for release notes management
  - Broken link at stevedore developer documentation
* Sun Oct  2 2016 dmueller@suse.com
- add source service to rpm-packaging and refresh
* Tue Aug 30 2016 tbechtold@suse.com
- update to 1.17.1:
  * do not emit warnings for missing hooks
  * Remove discover from test-requirements
  * make error reporting for extension loading quieter
  * Add Python 3.5 classifier and venv
  * Replace assertEquals() with assertEqual()
* Wed Jul 20 2016 tbechtold@suse.com
- update to 1.16.0:
  * Fix NamedExtensionManager fails when loading failing extension in order
  * Remove irrelated output item
  * Fix broken link about setuptools entry points
  * NamedExtensionManager: call a callback when some names cannot be found
  * Updated from global requirements
  * Trivial: ignore openstack/common in flake8 exclude list
  * dont claim copyright for future years
- Use pypi.io for Source url
* Thu Apr 21 2016 tbechtold@suse.com
- update to 1.12.0:
  * Add a reference to entry_point_inspector
  * Updated from global requirements
  * Trival:Remove unused logging import
  * Remove work around for NullHandler
  * remove unnecessary dependency on argparse
  * Use Stevedore exceptions for finding extensions
  * Clean up Python 2.6 related stuff
  * Updated from global requirements
  * Remove Python 2.6 classifier
  * cleanup tox.ini
  * Updated from global requirements
  * docs - Set pbr 'warnerrors' option for doc build
  * Add clarifying language to description of scanning for plugins
  * clean up default tox environment list
  * Show how to add a plugin in a separate package
  * replace the hard-coded history list with an auto-generated one
  * Fix spelling typo for maunal
  * Updated from global requirements
  * Examples typo fix
- Enable tests during build
* Wed Mar  9 2016 bwiedemann@suse.com
- use the year from changelog instead of current one
  to make reproducible rpms
* Wed Sep  9 2015 tbechtold@suse.com
- update to 1.8.0:
  * Updated from global requirements
* Mon Aug 31 2015 tbechtold@suse.com
- update to 1.7.0:
  * Updated from global requirements
  * Titlecase looks nicer sometimes in detailed mode
  * Update homepage to openstack hosted docs page
* Fri Jul 17 2015 tbechtold@suse.com
- update to 1.6.0:
  * Document the signature for check_func
  * Updated from global requirements
  * Switch badges from 'pypip.in' to 'shields.io'
  * Remove unnecessary openstack-common.conf
* Tue Jun 16 2015 tbechtold@suse.com
- update to 1.5.0:
  * Removed non-free color profile from .jpg
  * Add sphinx integration
  * Updated from global requirements
  * Fix Python versions supported
  * Remove run_cross_tests.sh
  * fix author contact details
  * re-raise exception with full traceback
  * Uncap library requirements for liberty
  * Add pypi download + version badges
  * Updated from global requirements
* Mon Mar 30 2015 tbechtold@suse.com
- update to 1.3.0:
  * Updated from global requirements
  * Fix test for finding multiple drivers
  * ignore .testrepository directory created by testr
  * clean up default environments run by tox
- Adjust Requires according to requirements.txt
* Tue Feb 24 2015 tbechtold@suse.com
- update to 1.2.0:
  * Use pkg_resources resolve(
  * Fix the README.rst file format for pypi
  * Workflow documentation is now in infra-manual
  * Implement a __contains__ override for extension manager
  * Update link to docs in README
  * Bring doc build up to standard
* Tue Oct 28 2014 dmueller@suse.com
- update to 1.1.0:
  * Add pbr to dependency list
  * Updated from global requirements
  * Add more detail to the README
  * Migrate tox to use testr
  * Update repository location in docs
* Tue Sep 23 2014 dmueller@suse.com
- add python-argparse dependency
* Sun Sep 21 2014 tbechtold@suse.com
- Add missing python-six Requires
* Fri Sep 19 2014 dmueller@suse.com
- update to 1.0:
  * Updated from global requirements
  * Fix incorrect image reference in documentation
  * Fix requirement handling in tox
  * Updated from global requirements
  * use six.add_metaclass
  * Updated from global requirements
  * driver: raise by default on import failure
  * Add doc requirements to venv environ
  * Import run_cross_tests.sh from oslo-incubator
  * fix link to entry point docs
* Fri Mar 28 2014 speilicke@suse.com
- Update to version 0.15:
  * Only log error when no load handler is set
  * Update readme with links to bug tracker and source
  * Update .gitreview after moving the repository
* Thu Feb 13 2014 speilicke@suse.com
- Update to version 0.14.1:
  + Fix the test manager implementation
- Changes from version 0.14.0t
  + Make requirements checking optional
  + Update docstrings
  + Allow a on_load_failure_callback to be provided
  + deprecate TestExtensionManager
* Mon Dec  2 2013 dmueller@suse.com
- update to 0.13:
  * Update documentation to refer to setuptools instead of distribute.
  * Add pypy to the list of default test configurations.
  * Include a work-around to avoid a cpython bug with atexit
  * Deprecate TestExtensionManager and replace with make_test_instance()
  class method to provide test classes that behave more like the
  production class, while still allowing the extensions to be injected
  for testing
  * Fixes an exception when reporting on an error where multiple
  drivers have the same name
  * Switch packaging to use pbr.
* Mon Sep  2 2013 dmueller@suse.com
- update to 0.11:
  * Fixes logging configuration under Python 2.6 with a NullHandler
* Thu Jul 11 2013 dmueller@suse.com
- update to 0.10:
  - Adds ``propagate_map_exceptions`` parameter to all of the extension
  managers which specifies whether exceptions are propagated up
  through the map call or logged and then ignored. The default is to
  preserve the current behavior of logging and ignoring exceptions.
- remove python-2.6.x.diff
* Fri Jun 21 2013 dmueller@suse.com
- add python-2.6.x.diff:
  * fix build on python 2.6
* Mon Jun 17 2013 speilicke@suse.com
- Update to version 0.9.1:
  + Add name_order parameter to NamedExtensionManager to coerce map() into
    processing the extensions in the order they are named when the manager is
    created, instead of the random order they may have been loaded.
  + Change the NamedDispatchExtensionManager to ignore missing extensions
    (issue 14).
  + Add __getitem__ to ExtensionManager for looking up individual plugins by
    name (issue 15).
  + Start working on the tutorial, Using Stevedore in Your Application.
- Drop semantic versioning hack
- Build HTML documentation
* Wed May 29 2013 dmueller@suse.com
- add compatibility provides of 0.8.0 version
  * needed for other packages that generate the version from
  * PyPi (where this is fetched when fetching 0.8.0)
* Sat Jan  5 2013 alexandre@exatati.com.br
- Update to 0.8:
  - Ignore AssertionError exceptions generated when plugins are
    loaded.
  - Update :class:`~stevedore.named.NamedExtensionManager` to check
    the name of a plugin before loading its code to avoid importing
    anything we are not going to use.
* Tue Dec  4 2012 alexandre@exatati.com.br
- Update to 0.7.2:
  - Fix logging support for Python 2.6.
- Aditional changes from 0.7.1:
  - Fix an issue with logging configuration.
- Aditional changes from 0.7:
  - Add memoization to the entrypoint scanning code in
    stevedore.extension.ExtensionManager to avoid performance issues
    in situations where lots of managers are instantiated with the
    same namespace argument.
* Wed Nov 21 2012 saschpe@suse.de
- Install LICENSE, README.rst and HTML documentation
* Mon Oct 29 2012 alexandre@exatati.com.br
- Update to 0.6:
  - Change the stevedore.enabled.EnabledExtensionManager to load
    the extension before calling the check function so the plugin
    can be asked if it should be enabled.
- Aditional changes from 0.5:
  - Add stevedore.tests.manager.TestExtensionManager for writing
    tests for classes that use extension managers.
* Sun Sep 16 2012 alexandre@exatati.com.br
- Update to 0.4:
  - Removed the name argument to plugin constructors.
  - Added driver property to stevedore.driver.DriverManager.
* Sun Aug 19 2012 alexandre@exatati.com.br
- Initial package (0.3) for openSUSE.
